@@ -40,6 +40,21 @@ class PPEComplianceConfig(BaseConfig):
     })
 
 class PPEComplianceUseCase(BaseProcessor):
+    def get_camera_info_from_stream(self, stream_info: Optional[Dict[str, Any]]) -> Dict[str, Any]:
+        """
+        Extract camera information from stream_info dict, matching mask_detection's approach.
+        """
+        if not stream_info:
+            return {"camera_name": None, "camera_group": None, "location": None}
+        input_settings = stream_info.get("input_settings", {})
+        camera_name = input_settings.get("camera_name")
+        camera_group = input_settings.get("camera_group")
+        location = input_settings.get("location")
+        return {
+            "camera_name": camera_name,
+            "camera_group": camera_group,
+            "location": location
+        }
     def _merge_or_register_track(self, raw_id: Any, bbox: Any) -> Any:
         """Return a stable canonical ID for a raw tracker ID, merging fragmented tracks when IoU and temporal constraints indicate they represent the same physical object."""
         if not hasattr(self, '_track_aliases'):
@@ -195,31 +210,47 @@ class PPEComplianceUseCase(BaseProcessor):
         # Track start time for "TOTAL SINCE" calculation
         self._tracking_start_time = None
     def _format_timestamp_for_video(self, timestamp: float) -> str:
-        """Format timestamp for video chunks (HH:MM:SS.ms format)."""
+        """Format timestamp for video chunks (HH:MM:SS.s format)."""
         hours = int(timestamp // 3600)
         minutes = int((timestamp % 3600) // 60)
-        seconds = timestamp % 60
-        return f"{hours:02d}:{minutes:02d}:{seconds:06.2f}"
+        seconds = round(float(timestamp % 60), 1)
+        return f"{hours:02d}:{minutes:02d}:{seconds:.1f}"
 
     def _format_timestamp_for_stream(self, timestamp: float) -> str:
         """Format timestamp for streams (YYYY:MM:DD HH:MM:SS format)."""
         dt = datetime.fromtimestamp(timestamp, tz=timezone.utc)
         return dt.strftime('%Y:%m:%d %H:%M:%S')
 
-    def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]]) -> str:
+    def _get_current_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False, frame_id: Optional[str]=None) -> str:
         """Get formatted current timestamp based on stream type."""
         if not stream_info:
             return "00:00:00.00"
-        is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
-        # if is_video_chunk:
-        #     video_timestamp = stream_info.get("video_timestamp", 0.0)
-        #     return self._format_timestamp_for_video(video_timestamp)
-        if stream_info.get("input_settings", {}).get("stream_type", "video_file") == "video_file":
-            # If video format, return video timestamp
-            stream_time_str = stream_info.get("video_timestamp", "")
-            return stream_time_str[:8]
+        # If precision is requested, use frame-based time for video files
+        if precision:
+            if stream_info.get("feed_type", "live") == "disk":
+                start_time = stream_info.get("start_frame", 30)/stream_info.get("original_fps", 30)
+            if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
+                if frame_id:
+                    start_time = int(frame_id)/stream_info.get("input_settings", {}).get("original_fps", 30)
+                else:
+                    start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
+                stream_time_str = self._format_timestamp_for_video(start_time)
+                return stream_time_str
+            else:
+                return datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+
+        if stream_info.get("feed_type", "live") == "disk":
+            start_time = stream_info.get("start_frame", 30)/stream_info.get("original_fps", 30)
+        if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
+            if frame_id:
+                start_time = int(frame_id)/stream_info.get("input_settings", {}).get("original_fps", 30)
+            else:
+                start_time = stream_info.get("input_settings", {}).get("start_frame", 30)/stream_info.get("input_settings", {}).get("original_fps", 30)
+            stream_time_str = self._format_timestamp_for_video(start_time)
+            return stream_time_str
         else:
-            stream_time_str = stream_info.get("stream_time", "")
+            # For streams, use stream_time from stream_info
+            stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
             if stream_time_str:
                 try:
                     timestamp_str = stream_time_str.replace(" UTC", "")
@@ -231,19 +262,21 @@ class PPEComplianceUseCase(BaseProcessor):
             else:
                 return self._format_timestamp_for_stream(time.time())
 
-    def _get_start_timestamp_str(self, stream_info: Optional[Dict[str, Any]]) -> str:
+    def _get_start_timestamp_str(self, stream_info: Optional[Dict[str, Any]], precision=False) -> str:
         """Get formatted start timestamp for 'TOTAL SINCE' based on stream type."""
         if not stream_info:
             return "00:00:00"
-        is_video_chunk = stream_info.get("input_settings", {}).get("is_video_chunk", False)
-        if is_video_chunk:
-            return "00:00:00"
-        elif stream_info.get("input_settings", {}).get("stream_type", "video_file") == "video_file":
-            # If video format, start from 00:00:00
+        if precision:
+            if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
+                return "00:00:00"
+            else:
+                return datetime.now(timezone.utc).strftime("%Y-%m-%d-%H:%M:%S.%f UTC")
+
+        if stream_info.get("input_settings", {}).get("start_frame", "na") != "na":
             return "00:00:00"
         else:
             if self._tracking_start_time is None:
-                stream_time_str = stream_info.get("stream_time", "")
+                stream_time_str = stream_info.get("input_settings", {}).get("stream_info", {}).get("stream_time", "")
                 if stream_time_str:
                     try:
                         timestamp_str = stream_time_str.replace(" UTC", "")
@@ -321,38 +354,19 @@ class PPEComplianceUseCase(BaseProcessor):
         summary = self._generate_summary(counting_summary, alerts)
 
         # Generate new-format output (agg_summary)
-        events_list = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
-        tracking_stats_list = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number, stream_info)
-        # No business_analytics for PPE, but keep key for compatibility
+        incidents = self._generate_events(counting_summary, alerts, config, frame_number, stream_info)
+        tracking_stats = self._generate_tracking_stats(counting_summary, insights, summary, config, frame_number, stream_info)
         business_analytics = {}
-        events = events_list[0] if events_list else {}
-        tracking_stats = tracking_stats_list[0] if tracking_stats_list else {}
-
-        # Compose new human_text dict for agg_summary
         app_name = "ppe_compliance"
         app_version = "1.2"
-        # Get incident human_text (first event if present)
-        incident_human_text = ""
-        if isinstance(events, list) and events and isinstance(events[0], dict):
-            incident_human_text = events[0].get("human_text", "")
-        elif isinstance(events, dict):
-            incident_human_text = events.get("human_text", "")
-        # Get tracking statistics human_text
-        tracking_human_text = ""
-        if isinstance(tracking_stats, dict):
-            tracking_human_text = tracking_stats.get("human_text", "")
-        elif isinstance(tracking_stats, list) and tracking_stats and isinstance(tracking_stats[0], dict):
-            tracking_human_text = tracking_stats[0].get("human_text", "")
-
         agg_human_text = {
             "Application Name": app_name,
             "Application Version": app_version,
-            "Incidents:": incident_human_text,
-            "Tracking Statistics:": tracking_human_text
+            "Incidents:": incidents.get("human_text", ""),
+            "Tracking Statistics:": tracking_stats.get("human_text", "")
         }
-
         agg_summary = {str(frame_number): {
-            "incidents": events,
+            "incidents": incidents,
             "tracking_stats": tracking_stats,
             "business_analytics": business_analytics,
             "alerts": alerts,
@@ -411,52 +425,28 @@ class PPEComplianceUseCase(BaseProcessor):
         self.reset_violation_tracking()
         self.logger.info("All PPE tracking state reset")
         
-    def _generate_events(self, counting_summary: Dict, alerts: List, config: PPEComplianceConfig, frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> List[Dict]:
-        """Generate structured events for the output format with frame-based keys."""
-        # Use frame number as key, fallback to 'current_frame' if not available
-        frame_key = str(frame_number) if frame_number is not None else "current_frame"
-        events = [{frame_key: []}]
-        frame_events = events[0][frame_key]
+    def _generate_events(self, counting_summary: Dict, alerts: List, config: PPEComplianceConfig, frame_number: Optional[int] = None, stream_info: Optional[Dict[str, Any]] = None) -> Dict:
         total_violations = counting_summary.get("total_count", 0)
-
-        # Generate human text in new format for incidents (match people_counting/mask_detection)
-        if total_violations > 0:
-            human_text = f"INCIDENTS DETECTED @ :\n\tSeverity Level: ('ppe_compliance', 'info')"
-            event = {
-                "type": "ppe_violation",
-                "severity": "info",
-                "category": "ppe",
-                "count": total_violations,
-                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
-                "location_info": None,
-                "human_text": human_text
-            }
-            frame_events.append(event)
-        else:
-            human_text = "INCIDENTS DETECTED @ :\n\tSeverity Level: ('ppe_compliance', 'none')"
-            event = {
-                "type": "ppe_violation",
-                "severity": "none",
-                "category": "ppe",
-                "count": 0,
-                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
-                "location_info": None,
-                "human_text": human_text
-            }
-            frame_events.append(event)
-        # Add alert events
-        for alert in alerts:
-            alert_event = {
-                "type": alert.get("type", "alert"),
-                "severity": alert.get("severity", "warning"),
-                "category": alert.get("category", "ppe"),
-                "count": alert.get("current_count", 0),
-                "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
-                "location_info": alert.get("zone"),
-                "human_text": alert.get("human_text", "PPE alert triggered")
-            }
-            frame_events.append(alert_event)
-        return events
+        severity = "info" if total_violations > 0 else "none"
+        human_text = f"INCIDENTS DETECTED @ :\n\tSeverity Level: ('ppe_compliance', '{severity}')"
+        incident = {
+            "incident_id": f"ppe_compliance_{frame_number}",
+            "incident_type": "ppe_compliance",
+            "severity_level": severity,
+            "human_text": human_text,
+            "start_time": "00:00:00",
+            "end_time": "00:00:00",
+            "camera_info": self.get_camera_info_from_stream(stream_info),
+            "level_settings": {
+                "low": 1,
+                "medium": 3,
+                "significant": 4,
+                "critical": 7
+            },
+            "alerts": alerts,
+            "alert_settings": [],
+        }
+        return incident
 
     def _generate_tracking_stats(
             self,
@@ -466,27 +456,15 @@ class PPEComplianceUseCase(BaseProcessor):
             config: PPEComplianceConfig,
             frame_number: Optional[int] = None,
             stream_info: Optional[Dict[str, Any]] = None
-    ) -> List[Dict]:
-        """Generate structured tracking stats for the output format with frame-based keys, including track_ids_info."""
-
-
-        frame_key = str(frame_number) if frame_number is not None else "current_frame"
-        tracking_stats = [{frame_key: []}]
-        frame_tracking_stats = tracking_stats[0][frame_key]
-
+    ) -> Dict:
         total_violations = counting_summary.get("total_count", 0)
         per_cat = counting_summary.get("per_category_count", {})
         cumulative = counting_summary.get("total_violation_counts", {})
         cumulative_total = sum(cumulative.values()) if cumulative else 0
-
         track_ids_info = self._get_track_ids_info(counting_summary.get("detections", []))
-
         current_timestamp = self._get_current_timestamp_str(stream_info)
         start_timestamp = self._get_start_timestamp_str(stream_info)
-
         human_text_lines = []
-
-        # CURRENT FRAME section
         human_text_lines.append(f"CURRENT FRAME @ {current_timestamp}:")
         if total_violations > 0:
             human_text_lines.append(f"\t- PPE Violations Detected: {total_violations}")
@@ -497,10 +475,7 @@ class PPEComplianceUseCase(BaseProcessor):
                     human_text_lines.append(f"\t\t- {label}: {count}")
         else:
             human_text_lines.append("\t- No PPE violations detected")
-
-        human_text_lines.append("")  # spacing
-
-        # TOTAL SINCE section
+        human_text_lines.append("")
         human_text_lines.append(f"TOTAL SINCE {start_timestamp}:")
         human_text_lines.append(f"\t- Total PPE Violations Detected: {cumulative_total}")
         for cat in ["NO-Hardhat", "NO-Mask", "NO-Safety Vest"]:
@@ -508,25 +483,29 @@ class PPEComplianceUseCase(BaseProcessor):
             if count > 0:
                 label = self.CATEGORY_DISPLAY.get(cat, cat).replace(" Violations", "")
                 human_text_lines.append(f"\t\t- {label}: {count}")
-
         human_text = "\n".join(human_text_lines)
-
         tracking_stat = {
-            "type": "ppe_tracking",
-            "category": "ppe",
-            "count": total_violations,
-            "insights": insights,
-            "summary": summary,
-            "timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S UTC'),
-            "human_text": human_text,
-            "track_ids_info": track_ids_info,
-            "global_frame_offset": getattr(self, '_global_frame_offset', 0),
-            "local_frame_id": frame_key,
-            "detections": counting_summary.get("detections", [])
+            "input_timestamp": datetime.now(timezone.utc).strftime('%Y-%m-%d-%H:%M:%S.%f UTC'),
+            "reset_timestamp": "00:00:00",
+            "camera_info": self.get_camera_info_from_stream(stream_info),
+            "total_counts": [
+                {"category": cat, "count": cumulative.get(cat, 0)} for cat in ["NO-Hardhat", "NO-Mask", "NO-Safety Vest"]
+            ],
+            "current_counts": [
+                {"category": cat, "count": per_cat.get(cat, 0)} for cat in ["NO-Hardhat", "NO-Mask", "NO-Safety Vest"] if per_cat.get(cat, 0) > 0
+            ],
+            "detections": counting_summary.get("detections", []),
+            "alerts": [],
+            "alert_settings": [],
+            "reset_settings": [
+                {
+                    "interval_type": "daily",
+                    "reset_time": {"value": 9, "time_unit": "hour"}
+                }
+            ],
+            "human_text": human_text
         }
-
-        frame_tracking_stats.append(tracking_stat)
-        return tracking_stats
+        return tracking_stat
 
     def _count_categories(self, detections: list, config: PPEComplianceConfig) -> dict:
         """
